==> jc-1.4.0.tar.gz: soot/javaToJimple/AnonClassChecker.h <==
// public class soot.javaToJimple.AnonClassChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 61b0e72f9859dd6b soot_javaToJimple_AnonClassChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_AnonClassChecker_H_
#define _JC_soot_javaToJimple_AnonClassChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AnonClassChecker$sub_refs	_jc_soot_javaToJimple_AnonClassChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs	_jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$refs	_jc_soot_javaToJimple_AnonClassChecker$refs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$nonrefs	_jc_soot_javaToJimple_AnonClassChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$object	_jc_soot_javaToJimple_AnonClassChecker$object;

typedef const struct _jc_soot_javaToJimple_AnonClassChecker$vmethods	_jc_soot_javaToJimple_AnonClassChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_AnonClassChecker$vtable	_jc_soot_javaToJimple_AnonClassChecker$vtable;
typedef const struct _jc_soot_javaToJimple_AnonClassChecker$vtype	_jc_soot_javaToJimple_AnonClassChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AnonClassChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_soot_javaToJimple_AnonClassChecker$method$enter$0698e71b16532e07(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_AnonClassChecker$method$getBodyNameMap$f85021aede1fca19(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *);
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_AnonClassChecker$method$getMap$f4cb77aab22032d5(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AnonClassChecker$method_info$enter$0698e71b16532e07;
extern _jc_method _jc_soot_javaToJimple_AnonClassChecker$method_info$getBodyNameMap$f85021aede1fca19;
extern _jc_method _jc_soot_javaToJimple_AnonClassChecker$method_info$getMap$f4cb77aab22032d5;

// Virtual methods structure
struct _jc_soot_javaToJimple_AnonClassChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$0698e71b16532e07)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_java_util_HashMap$object	*(*getBodyNameMap$f85021aede1fca19)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *);
	struct _jc_java_util_HashMap$object	*(*getMap$f4cb77aab22032d5)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *);
};

// Vtable
struct _jc_soot_javaToJimple_AnonClassChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_AnonClassChecker$vmethods	soot_javaToJimple_AnonClassChecker;
};

// Vtype
struct _jc_soot_javaToJimple_AnonClassChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AnonClassChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassChecker$sub_refs {
	struct _jc_java_util_HashMap$object	*map;
	struct _jc_java_util_HashMap$object	*bodyNameMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassChecker$refs {
    _jc_soot_javaToJimple_AnonClassChecker$sub_refs	soot_javaToJimple_AnonClassChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs	soot_javaToJimple_AnonClassChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_AnonClassChecker$object {
	_jc_soot_javaToJimple_AnonClassChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AnonClassChecker$vtype	*vtype;
	_jc_soot_javaToJimple_AnonClassChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AnonClassChecker$vtype _jc_soot_javaToJimple_AnonClassChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AnonClassChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AnonClassChecker$class_object;

#endif	/* _JC_soot_javaToJimple_AnonClassChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/AnonClassChecker.h <==
// public class soot.javaToJimple.AnonClassChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 61b0e72f9859dd6b soot_javaToJimple_AnonClassChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_AnonClassChecker_H_
#define _JC_soot_javaToJimple_AnonClassChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AnonClassChecker$sub_refs	_jc_soot_javaToJimple_AnonClassChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs	_jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$refs	_jc_soot_javaToJimple_AnonClassChecker$refs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$nonrefs	_jc_soot_javaToJimple_AnonClassChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassChecker$object	_jc_soot_javaToJimple_AnonClassChecker$object;

typedef const struct _jc_soot_javaToJimple_AnonClassChecker$vmethods	_jc_soot_javaToJimple_AnonClassChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_AnonClassChecker$vtable	_jc_soot_javaToJimple_AnonClassChecker$vtable;
typedef const struct _jc_soot_javaToJimple_AnonClassChecker$vtype	_jc_soot_javaToJimple_AnonClassChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AnonClassChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_soot_javaToJimple_AnonClassChecker$method$enter$0698e71b16532e07(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_AnonClassChecker$method$getBodyNameMap$f85021aede1fca19(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_AnonClassChecker$method$getMap$f4cb77aab22032d5(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AnonClassChecker$method_info$enter$0698e71b16532e07;
extern _jc_method _jc_soot_javaToJimple_AnonClassChecker$method_info$getBodyNameMap$f85021aede1fca19;
extern _jc_method _jc_soot_javaToJimple_AnonClassChecker$method_info$getMap$f4cb77aab22032d5;

// Virtual methods structure
struct _jc_soot_javaToJimple_AnonClassChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$0698e71b16532e07)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_util_HashMap$object	*(*getBodyNameMap$f85021aede1fca19)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_HashMap$object	*(*getMap$f4cb77aab22032d5)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassChecker$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_AnonClassChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_AnonClassChecker$vmethods	soot_javaToJimple_AnonClassChecker;
};

// Vtype
struct _jc_soot_javaToJimple_AnonClassChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AnonClassChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassChecker$sub_refs {
	struct _jc_java_util_HashMap$object	*map;
	struct _jc_java_util_HashMap$object	*bodyNameMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassChecker$refs {
    _jc_soot_javaToJimple_AnonClassChecker$sub_refs	soot_javaToJimple_AnonClassChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_AnonClassChecker$sub_nonrefs	soot_javaToJimple_AnonClassChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_AnonClassChecker$object {
	_jc_soot_javaToJimple_AnonClassChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AnonClassChecker$vtype	*vtype;
	_jc_soot_javaToJimple_AnonClassChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AnonClassChecker$vtype _jc_soot_javaToJimple_AnonClassChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AnonClassChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AnonClassChecker$class_object;

#endif	/* _JC_soot_javaToJimple_AnonClassChecker_H_ */
